"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _reactNative = require("react-native");
var _react = _interopRequireWildcard(require("react"));
var _reactNativeModal = _interopRequireDefault(require("react-native-modal"));
var _flashList = require("@shopify/flash-list");
var _assets = require("../../assets");
var _compareSearchText = _interopRequireDefault(require("../../helpers/compareSearchText"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const itemHeight = 45;
const borderRadius = 7;
const colors = {
  white: '#ffffff',
  border: '#D2D2D2',
  pressed: '#f2f2f2',
  disable: '#ededed',
  text: '#333333'
};
const Picker = props => {
  const {
    width,
    height
  } = (0, _reactNative.useWindowDimensions)();
  const {
    data,
    value,
    onChange,
    placeholder,
    search,
    searchPlaceholder = 'Enter keyword',
    disable,
    containerStyle,
    inputSearchStyle,
    closeIcon,
    renderItem,
    multiple,
    renderArrow
  } = props;
  const [showPicker, setShowPicker] = (0, _react.useState)(false);
  const [keyword, setKeyword] = (0, _react.useState)('');
  const [keyboardShown, setKeyboardShown] = (0, _react.useState)(false);
  (0, _react.useEffect)(() => {
    const keyboardDidShowListener = _reactNative.Keyboard.addListener('keyboardDidShow', () => setKeyboardShown(true));
    const keyboardDidHideListener = _reactNative.Keyboard.addListener('keyboardDidHide', () => setKeyboardShown(false));
    return () => {
      keyboardDidHideListener.remove();
      keyboardDidShowListener.remove();
    };
  }, []);
  (0, _react.useEffect)(() => {
    setKeyword('');
  }, [showPicker]);
  const dataFiltered = (0, _react.useMemo)(() => [...data.filter(e => (0, _compareSearchText.default)(e.label, keyword)), {
    label: '',
    value: ''
  }], [data, keyword]);
  const selectedItem = (0, _react.useMemo)(() => data.find(e => e.value === value), [value, data]);
  const handleClickItem = itemValue => {
    if (multiple) {
      if (value.includes(itemValue)) {
        onChange(value.filter(e => e !== itemValue));
      } else {
        onChange([...value, itemValue]);
      }
    } else {
      onChange(itemValue);
      setShowPicker(false);
    }
  };
  const _renderArrow = () => {
    if (renderArrow) {
      return renderArrow(showPicker);
    } else {
      return /*#__PURE__*/_react.default.createElement(_reactNative.Image, {
        source: showPicker ? _assets.IMAGES.IC_UP : _assets.IMAGES.IC_DOWN,
        style: {
          width: 11,
          height: 11
        }
      });
    }
  };
  const _renderItem = (0, _react.useCallback)(({
    item
  }) => {
    const isSelected = item.value === '' ? false : Array.isArray(value) ? value.includes(item.value) : value === item.value;
    return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: {
        backgroundColor: colors.pressed
      }
    }, /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
      onPress: () => handleClickItem(item.value),
      disabled: item.value === '',
      activeOpacity: 0.5
    }, renderItem ? renderItem({
      item,
      isSelected
    }) : /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
      style: [styles.item, {
        backgroundColor: isSelected ? colors.pressed : colors.white
      }]
    }, item.label)));
  }, [multiple, onChange, value]);
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.container, containerStyle]
  }, /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    onPress: () => disable ? null : setShowPicker(!showPicker),
    activeOpacity: disable ? 1 : 0.5,
    style: [styles.containerButton, {
      backgroundColor: disable ? colors.disable : colors.white
    }]
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    numberOfLines: 1
  }, (selectedItem === null || selectedItem === void 0 ? void 0 : selectedItem.label) || placeholder), _renderArrow())), Array.isArray(value) && /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: {
      flexDirection: 'row',
      flexWrap: 'wrap',
      gap: 2,
      marginBottom: 8,
      marginTop: 6
    }
  }, value.map(item => {
    const itemFound = data.find(e => e.value === item);
    if (!itemFound) {
      return null;
    }
    return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
      key: item,
      onPress: () => handleClickItem(item),
      style: {
        flexDirection: 'row',
        alignItems: 'center',
        backgroundColor: colors.pressed,
        paddingVertical: 3,
        paddingHorizontal: 10,
        borderRadius: 100
      }
    }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
      style: {
        fontSize: 11,
        color: colors.text,
        paddingEnd: 3
      }
    }, itemFound.label), /*#__PURE__*/_react.default.createElement(_reactNative.Image, {
      source: _assets.IMAGES.IC_CLOSE,
      style: {
        width: 8,
        height: 8
      }
    }));
  })), /*#__PURE__*/_react.default.createElement(_reactNativeModal.default, {
    deviceWidth: width,
    deviceHeight: height,
    isVisible: showPicker,
    animationIn: 'slideInUp',
    animationOut: 'slideOutDown',
    statusBarTranslucent: true,
    backdropOpacity: 0.3,
    style: {
      margin: 0,
      padding: 0
    }
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.modalWrapper
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: {
      backgroundColor: colors.white,
      maxHeight: height / 1.2,
      height: keyboardShown ? height : itemHeight * (data.length + 5)
    }
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.modalHeader
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.modalTitleWrapper
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: styles.modalTitle,
    numberOfLines: 1
  }, placeholder), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.modalCloseIconWrapper
  }, /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    onPress: () => setShowPicker(false),
    style: styles.modalCloseIcon
  }, closeIcon ? closeIcon() : /*#__PURE__*/_react.default.createElement(_reactNative.Image, {
    source: _assets.IMAGES.IC_CLOSE,
    style: {
      width: 13,
      height: 13
    }
  })))), search && /*#__PURE__*/_react.default.createElement(_reactNative.TextInput, {
    cursorColor: colors.text,
    style: [styles.inputSearch, inputSearchStyle],
    value: keyword,
    onChangeText: setKeyword,
    placeholder: searchPlaceholder
  })), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.listWrapper
  }, /*#__PURE__*/_react.default.createElement(_flashList.FlashList, {
    bounces: false,
    data: dataFiltered,
    extraData: value,
    estimatedItemSize: 100,
    renderItem: _renderItem,
    ItemSeparatorComponent: () => /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: styles.itemSeparator
    })
  }))))));
};
var _default = exports.default = Picker;
const styles = _reactNative.StyleSheet.create({
  container: {
    borderWidth: 1,
    borderColor: colors.border,
    borderRadius: borderRadius,
    backgroundColor: colors.pressed,
    overflow: 'hidden',
    height: itemHeight
  },
  containerButton: {
    flex: 1,
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'center',
    paddingHorizontal: 10
  },
  modalWrapper: {
    flex: 1,
    justifyContent: 'flex-end'
  },
  modalHeader: {
    borderBottomWidth: 1,
    borderBottomColor: colors.border,
    overflow: 'hidden'
  },
  modalTitleWrapper: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'space-between'
  },
  modalTitle: {
    color: colors.text,
    fontWeight: 'bold',
    paddingHorizontal: 16,
    height: itemHeight,
    textAlignVertical: 'center'
  },
  modalCloseIconWrapper: {
    backgroundColor: colors.pressed
  },
  modalCloseIcon: {
    width: itemHeight,
    height: itemHeight,
    justifyContent: 'center',
    alignItems: 'center',
    backgroundColor: colors.white
  },
  inputSearch: {
    height: itemHeight,
    borderWidth: 1,
    borderColor: colors.border,
    marginHorizontal: 16,
    marginTop: 0,
    marginBottom: 12,
    borderRadius: borderRadius,
    paddingHorizontal: 10
  },
  listWrapper: {
    flex: 1,
    minHeight: 10
  },
  item: {
    color: colors.text,
    paddingHorizontal: 10,
    height: itemHeight,
    justifyContent: 'center',
    textAlignVertical: 'center'
  },
  itemSeparator: {
    height: 1,
    backgroundColor: colors.border
  }
});
//# sourceMappingURL=index.js.map